<!--特殊巡检台账-->
<template>
  <div class="bbsl-common-page">
    <template v-if="componentName === 'table'">
      <div class="bbsl-table-search">
        <el-form v-model="queryParams" :inline="true" label-suffix="：">
          <el-form-item label="巡查计划名称">
            <el-input
              :clearable="true"
              placeholder="请输入巡查计划名称"
              v-model="queryParams.inspectionPlanName"
            />
          </el-form-item>
          <el-form-item label="巡查时间" prop="inspectionPlanTime">
            <el-date-picker
              clearable
              type="date"
              value-format="yyyy-MM-dd"
              style="width:100%"
              placeholder="请选择巡查时间"
              v-model="queryParams.inspectionPlanTime"
            ></el-date-picker>
          </el-form-item>
          <el-form-item>
            <el-button type="primary" icon="el-icon-search" @click="handleSearch">
              搜索
            </el-button>
            <el-button icon="el-icon-refresh" @click="handleReset">
              重置
            </el-button>
          </el-form-item>
        </el-form>
      </div>
      <div class="bbsl-table-content" ref="contentPanel">
        <div class="bbsl-btn-content" ref="btnPanel">

        </div>
        <el-table
          border
          size="mini"
          v-loading="loading"
          ref="multipleSelection"
          :data="tableData"
          :style="{width: '100%'}"
          :max-height="tableMaxHeight"
          :cell-style="{'text-align': 'center'}"
          :header-cell-style="{'text-align': 'center'}"
          @selection-change="handleSelectionChange"
          @sort-change="sortChange"
          row-key="id"
        >
          <el-table-column type="index" width="70" label="序号" align="center">
          </el-table-column>
          <el-table-column
            prop="inspectionPlanName"
            show-overflow-tooltip
            align="center"
            label="巡检计划名称"
            min-width="150"
          />
          <el-table-column
            prop="inspectionContent"
            show-overflow-tooltip
            align="center"
            label="巡检内容"
            min-width="150"
          />
          <el-table-column
            prop="inspectionPlanTime"
            show-overflow-tooltip
            min-width="100"
            align="center"
            label="巡检时间"
          />
          <el-table-column
            prop="inspectionType"
            show-overflow-tooltip
            align="center"
            label="巡检类型"
            min-width="100"
            :formatter="({inspectionType}) => dictionaryEscape(inspectionTypeOpt,inspectionType)"
          />
          <el-table-column show-overflow-tooltip min-width="80" align="center" fixed="right" label="操作">
            <template v-slot="{ row }">
              <el-link
                type="primary"
                :underline="false"
                @click="openPage('deviceListPage',row)"
                style="margin-right: 15px"
              >
                录入结果
              </el-link>
              <el-link
                type="warning"
                :underline="false"
                @click="showDialog('equipmentAddDialog',row)"
              >
                添加巡检设备
              </el-link>
            </template>
          </el-table-column>
        </el-table>
        <el-pagination
          align="right"
          background
          class="bbsl-pagination"
          ref="paginationPanel"
          @size-change="handleSizeChange"
          @current-change="handleCurrentChange"
          :current-page="queryParams.pageNum"
          :page-sizes="[20, 30, 40, 50]"
          :page-size="queryParams.pageSize"
          layout="total, sizes, prev, pager, next, jumper"
          :total="queryParams.total"
        ></el-pagination>
      </div>
    </template>

    <!--  设备列表页面  -->
    <DeviceListPage
      v-if="componentName === 'deviceListPage'"
      :row-info="rowInfo"
      @closePage="closePage"
    />

    <!--  新增巡检设备弹层  -->
    <EquipmentAddDialog
      :equipmentAddDialog.sync="equipmentAddDialog"
      :row-info="rowInfo"
      @closeDialog="closeDialog"
    />
  </div>
</template>

<script>
import {TableMixin} from '@/mixins/tableMixin'
import {inspectionPlanTable} from '@/api/device/resourceInspection/inspectionLedger'
import dictUtils from '@/components/dict/DictSelectUtils'
import {dictionaryEscape} from '@/utils/dictionary'
import DeviceListPage from './components/DeviceListPage/index.vue'
import EquipmentAddDialog from './components/EquipmentAddDialog/index.vue'

export default {
  name: 'SpecialInspection',
  components: {EquipmentAddDialog, DeviceListPage},
  // 日常巡检
  mixins: [TableMixin],
  data() {
    return {
      isShowAddModify: false,
      tableData: [],
      queryParams: {
        areaName: '',
        inspectionContent: '',
        inspectionDeviceStatus: '',
        inspectionPlanName: '',
        inspectionPlanTime: '',
        inspectionStatus: '',
        inspectionType: '3',
        name: '',
        productId: '',
        pageNum: 1,
        pageSize: 10,
        total: 0
      },
      sorter: [],
      inspectionTypeOpt: dictUtils.getDictItemsFromCache('xjlx') || [],
      rowInfo: {},
      componentName: 'table',
      equipmentAddDialog: false // 是否展示计划新增弹层
    }
  },
  computed: {},
  created() {
  },
  methods: {
    dictionaryEscape,

    // 获取list
    async loadData() {
      this.loading = true
      const {rows, total} = await inspectionPlanTable(this.queryParams)
      this.tableData = rows
      this.queryParams.total = total
      this.loading = false
    },

    // 顶部搜索
    handleSearch() {
      this.loadData()
    },

    // 重置
    handleReset() {
      this.queryParams = this.$options.data().queryParams
      this.loadData()
    },

    //分页页数
    handleCurrentChange(pageNum) {
      this.queryParams.pageNum = 1
      this.queryParams.pageNum = pageNum
      this.loadData()
    },

    //分页大小
    handleSizeChange(pageSize) {
      this.queryParams.pageNum = 1
      this.queryParams.pageSize = pageSize
      this.loadData()
    },

    // 排序切换
    sortChange({prop: property, order}) {
      let direction = ''
      switch (order) {
        case 'ascending':
          direction = 'ASC'
          break
        case 'descending':
          direction = 'DESC'
          break
      }
      this.sorter.forEach(i => {
        if (i.property !== property) return i.direction = ''
        i.direction = direction
      })
      this.loadData()
    },

    // 打开功能页面
    openPage(dialog, rowInfo = {}) {
      this.componentName = dialog
      this.rowInfo = rowInfo // 保存点击行信息
    },

    // 关闭功能页面
    closePage(args) {
      switch (args) {
        case 'deviceListPage':
          break
      }
      this.componentName = 'table'
      this.rowInfo = {}
    },

    // 打开弹层
    showDialog(dialog, rowInfo = {}) {
      this.rowInfo = rowInfo // 保存点击行信息
      this[dialog] = true
    },

    // 关闭弹层
    closeDialog(event) {
      switch (event) {
        case 'equipmentAddDialog':
          this.loadData()
          break
      }
      this.rowInfo = {}
    }
  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}
</style>
